@@ -1,10 +1,11 @@
 import os
 import sys
 
-from . import (copy, execute, getPath, makeFolder, makeTempWorkspace, readFile,
+from . import (copy, getPath, makeFolder, makeTempWorkspace, readFile,
                remove, writeFile)
-from .bytes import decode
+from .byte import decode
 from .zip import zipFileExtract
+from .execute import execute
 
 
 def main():
@@ -17,7 +18,7 @@ def main():
         func(*parList)
     else:
         # 没有输入命令
-        exit(None, True)
+        exit("", True)
 
 
 helpInfo = '''
@@ -36,7 +37,7 @@ funcNameList = [
 ]
 
 
-def task_create(targetPath=None):
+def task_create(targetPath: str = ""):
     targetPath = targetPath or os.getcwd()
     makeFolder(targetPath)
     workspaceFolder = makeTempWorkspace()
@@ -56,12 +57,14 @@ def task_create(targetPath=None):
         remove(workspaceFolder)
 
 
-def task_build(targetPath=None):
+def task_build(targetPath: str = ""):
+    currentPath: str = ""
+    workspaceFolder: str = ""
     try:
-        ignoreList = ["main.py"]
         currentPath = os.getcwd()
         targetPath = targetPath or currentPath
         workspaceFolder = makeTempWorkspace()
+        ignoreList = ["main.py"]
         mainPyFile = getPath(targetPath, "project/src/main.py")
         if not os.path.isfile(mainPyFile):
             exit(f"发布失败，主文件不存在 {mainPyFile}")
@@ -89,7 +92,7 @@ def task_build(targetPath=None):
         # PyInstaller.__main__.run() # pyinstaller main.py -F
 
         os.chdir(workspaceFolder)
-        _returncode, outBytes, errBytes = execute(f"pyinstaller {taskSpecFile}", ignoreError=True)
+        _, outBytes, errBytes = execute(f"pyinstaller {taskSpecFile}", ignoreError=True)
 
         outStr = decode(outBytes).replace("\r\n", "\n")
         errStr = decode(errBytes).replace("\r\n", "\n")
@@ -103,11 +106,13 @@ def task_build(targetPath=None):
         remove(toExeFile)
         copy(fromExeFile, toExeFile)
     finally:
-        os.chdir(currentPath)
-        remove(workspaceFolder)
+        if currentPath:
+            os.chdir(currentPath)
+        if workspaceFolder:
+            remove(workspaceFolder)
 
 
-def exit(errorMsg, isShowHelpInfo=False):
+def exit(errorMsg: str, isShowHelpInfo: bool = False):
     if errorMsg:
         print(errorMsg)
     if isShowHelpInfo:
