@@ -2,6 +2,7 @@ import datetime
 import os
 import sys
 import time
+from functools import cache
 from typing import Any, Optional
 
 from . import (getAllFileList, getFileBaseName, getPath, hold, makeFolder,
@@ -20,7 +21,7 @@ _workspacePath: str = ""
 
 def initTask(exeWorkspace: str, devWorkspace: str, devTaskList: list[TaskDataType]):
     global _workspacePath
-    if _isDev():
+    if isTaskByDev():
         _workspacePath = getPath(devWorkspace)
         _runTaskList(devTaskList)
     else:
@@ -44,8 +45,8 @@ def runTask(moduleName: str, **parDict: dict[str, Any]):
     if hasattr(module, "clean"):
         module.clean()
 
-
-def _isDev():
+@cache
+def isTaskByDev():
     return sys.executable.endswith("python.exe")
 
 
@@ -84,7 +85,7 @@ def _runTaskFile(file: str):
                 moduleName = line
             taskList.append((moduleName, parDict))
         assert len(taskList) > 0
-        os.system(f"title={getFileBaseName(file)}")
+        os.system(f"title {getFileBaseName(file)}")
     except:
         isException = True
         import traceback
@@ -157,6 +158,6 @@ def _runTaskList(taskList: list[TaskDataType]):
         if lockFile:
             remove(lockFile)
 
-        if not _isDev():
+        if not isTaskByDev():
             while True:
                 time.sleep(1)
