@@ -1,23 +1,25 @@
 import os
-from typing import Optional
+from typing import Callable, Optional, Union
 from zipfile import ZIP_DEFLATED, ZipFile
 
 from . import getAllFileAndFolderList, makeFolder
 
 
-def zipFile(toFile: str, fileFolderOrAry, rename=None):
+def zipFile(toFile: str, fileFolderOrAry: Union[str, list[str]], rename: Optional[Callable[[str], str]] = None):
     makeFolder(os.path.dirname(toFile))
-    ary = fileFolderOrAry
-    if type(ary) != list:
-        ary = [fileFolderOrAry]
+    fileList: list[str] = []
+    if type(fileFolderOrAry) is list:
+        fileList = fileFolderOrAry
+    elif type(fileFolderOrAry) is str:
+        fileList = [fileFolderOrAry]
     rename = rename or (lambda x: os.path.basename(x))
     with ZipFile(toFile, 'w', ZIP_DEFLATED) as f:
-        for file in sorted(ary):
+        for file in sorted(fileList):
             fname = rename(file)
             f.write(file, fname)
 
 
-def zipFileForFolder(toFile: str, folder: str, rename=None, filterFun=None):
+def zipFileForFolder(toFile: str, folder: str, rename: Optional[Callable[[str], str]] = None, filterFun: Optional[Callable[[str], bool]] = None):
     if not folder.endswith(os.path.sep):
         folder += os.path.sep
     rename = rename or (lambda x: x[len(folder):])
